require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_keyvaluepairfile',
  dscmeta_resource_friendly_name: 'KeyValuePairFile',
  dscmeta_resource_name: 'DSR_KeyValuePairFile',
  dscmeta_module_name: 'FileContentDsc',
  dscmeta_module_version: '1.3.0.151',
  docs: 'The DSC KeyValuePairFile resource type.
         Automatically generated from version 1.3.0.151',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_text: {
      type: 'Optional[String]',
      desc: "The text to replace the value with in the identified key. Only used when Type is set to 'Text'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ensure: {
      type: "Optional[Enum['Present', 'Absent']]",
      desc: 'Specifies the if the key value pair with the specified key should exist in the file.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_type: {
      type: "Optional[Enum['Text', 'Secret']]",
      desc: "Specifies the value type to use as the replacement string. Defaults to 'Text'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_path: {
      type: 'String',
      desc: 'The path to the key value pair text file.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_secret: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: "The secret text to replace the value with in the identified key. Only used when Type is set to 'Secret'.",
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_name: {
      type: 'String',
      desc: 'The name of the key.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_ignorenamecase: {
      type: 'Optional[Boolean]',
      desc: 'Ignore the case of the name of the key. Defaults to $False.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_ignorevaluecase: {
      type: 'Optional[Boolean]',
      desc: 'Ignore the case of any text or secret when determining if it they need to be updated. Defaults to $False.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
    dsc_encoding: {
      type: "Optional[Enum['ASCII', 'BigEndianUnicode', 'BigEndianUTF32', 'UTF8', 'UTF32']]",
      desc: 'Specifies the file encoding. Defaults to ASCII',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
  },
)
