require 'puppet/resource_api'

Puppet::ResourceApi.register_type(
  name: 'dsc_replacetext',
  dscmeta_resource_friendly_name: 'ReplaceText',
  dscmeta_resource_name: 'DSR_ReplaceText',
  dscmeta_module_name: 'FileContentDsc',
  dscmeta_module_version: '1.3.0.151',
  docs: 'The DSC ReplaceText resource type.
         Automatically generated from version 1.3.0.151',
  features: ['simple_get_filter', 'canonicalize'],
  attributes: {
    name: {
      type:      'String',
      desc:      'Description of the purpose for this resource declaration.',
      behaviour: :namevar,
    },
    dsc_psdscrunascredential: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: ' ',
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_text: {
      type: 'Optional[String]',
      desc: "The text to replace the text identified by the RegEx. Only used when Type is set to 'Text'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_type: {
      type: "Optional[Enum['Text', 'Secret']]",
      desc: "Specifies the value type to use as the replacement string. Defaults to 'Text'.",

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_search: {
      type: 'String',
      desc: 'The RegEx string to use to search the text file.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_secret: {
      type: 'Optional[Struct[{ user => String[1], password => Sensitive[String[1]] }]]',
      desc: "The secret text to replace the text identified by the RegEx. Only used when Type is set to 'Secret'.",
      behaviour: :parameter,
      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'PSCredential',
      mof_is_embedded: true,
    },
    dsc_path: {
      type: 'String',
      desc: 'The path to the text file to replace the string in.',
      behaviour: :namevar,
      mandatory_for_get: true,
      mandatory_for_set: true,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_encoding: {
      type: "Optional[Enum['ASCII', 'BigEndianUnicode', 'BigEndianUTF32', 'UTF8', 'UTF32']]",
      desc: 'Specifies the file encoding. Defaults to ASCII',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'String',
      mof_is_embedded: false,
    },
    dsc_allowappend: {
      type: 'Optional[Boolean]',
      desc: 'Specifies to append text to the file being modified. Adds the ability to add a configuration entry.',

      mandatory_for_get: false,
      mandatory_for_set: false,
      mof_type: 'Boolean',
      mof_is_embedded: false,
    },
  },
)
